@@ -1,6 +1,6 @@
 package XTaTIK;
 
-our $VERSION = '0.001002'; # VERSION
+our $VERSION = '0.002001'; # VERSION
 
 use Mojo::Base 'Mojolicious';
 
@@ -69,6 +69,14 @@ sub startup {
 
     $ENV{SASS_PATH} = join ':', @sass_path;
 
+    $self->log->debug('*** XTaTIK LOADED: ***');
+    $self->log->debug('Site: ' . $self->config('site') );
+    $self->log->debug("XTATIK_COMPANY: $ENV{XTATIK_COMPANY}");
+    $self->log->debug("XTATIK_SITE_ROOT: $ENV{XTATIK_SITE_ROOT}");
+    $self->log->debug("Silo path: $silo_path");
+    $self->log->debug("SASS path: $ENV{SASS_PATH}");
+    $self->log->debug('**********************');
+
     $self->secrets([ $self->config('mojo_secrets') ]);
 
     $self->config( hypnotoad => {listen => ['http://*:3005'], proxy => 1} );
@@ -143,7 +151,8 @@ sub startup {
     $self->helper(
         blog => sub {
             state $blog = XTaTIK::Model::Blog->new(
-                blog_root => catfile $silo_path, 'blog_src'
+                blog_root => $ENV{XTATIK_BLOG_SRC}
+                    // catfile $silo_path, 'blog_src'
             );
         }
     );
@@ -284,11 +293,13 @@ sub _gen_helper_product_search {
 sub _helper_products {
     my $c = shift;
     state $products = XTaTIK::Model::Products->new(
-        pricing_region => $c->geoip_region,
         pg => $PG,
         custom_cat_sorting => $c->config('custom_cat_sorting'),
         site => $c->config('site'),
     );
+
+    $products->pricing_region( $c->geoip_region );
+    return $products;
 };
 
 sub _helper_quotes {
@@ -347,7 +358,7 @@ __END__
 
 =encoding utf8
 
-=for stopwords eCommerce Analytics GeoIP Perlbrew PostgreSQL deployable  jQuery
+=for stopwords eCommerce Analytics GeoIP Perlbrew PostgreSQL deployable  jQuery Cassi
 
 
 =head1 NAME
@@ -492,8 +503,7 @@ you desire, you may need to be familiar with some of them:
 
 =item * L<jQuery|https://jquery.com/>
 
-=item * L<PostgreSQL|http://www.postgresql.org/> (other databases
-    might be supported in the future)
+=item * L<PostgreSQL|http://www.postgresql.org/>
 
 =item * L<Mojolicious> (also, see
      L<www.mojolicio.us|http://www.mojolicio.us/>)
