@@ -1,9 +1,9 @@
 package XTaTIK::Controller::Cart;
 
-our $VERSION = '0.001002'; # VERSION
+our $VERSION = '0.002001'; # VERSION
 
 use Mojo::Base 'Mojolicious::Controller';
-
+use XTaTIK::Common qw/n_to_br  find_product_pic/;
 use experimental 'postderef';
 
 my @CHECKOUT_FORM_FIELDS = qw/
@@ -14,7 +14,11 @@ my @CHECKOUT_FORM_FIELDS = qw/
 sub index {
     my $self = shift;
 
-    $self->stash( $self->cart->all_items_cart_quote_kv );
+    my %items = $self->cart->all_items_cart_quote_kv;
+    for ( $items{cart}->@*, $items{quote}->@*) {
+        find_product_pic( $self, $_->{image} );
+    }
+    $self->stash( %items );
 };
 
 sub thank_you {
@@ -39,7 +43,7 @@ sub add {
     $self->stash(
         number    => $self->param('number'),
         quantity  => $self->param('quantity'),
-        is_quote  => $p->{price} > 0 ? 0 : 1,
+        is_quote  => $p->{price}//0 > 0 ? 0 : 1,
         return_to => $self->req->headers->referrer || '/products',
     );
 };
@@ -68,9 +72,10 @@ sub checkout {
         $self->param( $_ => $self->session($_) );
     }
 
-    $self->stash(
-        $self->cart->all_items_cart_quote_kv,
-    );
+    my %items = $self->cart->all_items_cart_quote_kv;
+    $items{cart}->@* or $items{quote}->@*
+        or return $self->redirect_to('/cart/');
+    $self->stash( %items );
 }
 
 sub checkout_review {
